@@ -1,3 +1,6 @@
+import cycler as cycler
+import matplotlib.pyplot as plt
+
 from RWTHColors.colors import *
 
 
@@ -20,6 +23,20 @@ class ColorManager:
         self.RWTHViolett = RWTHViolett()
         self.RWTHLila = RWTHLila()
 
+        self.rwth_color_cycle = cycler(color=[self.RWTHBlau.p(100),
+                                              self.RWTHOrange.p(100),
+                                              self.RWTHGruen.p(100),
+                                              self.RWTHRot.p(100),
+                                              self.RWTHViolett.p(100),
+                                              self.RWTHBordeaux.p(100),
+                                              self.RWTHLila.p(100),
+                                              self.RWTHPetrol.p(100),
+                                              self.RWTHMaiGruen.p(100),
+                                              self.RWTHPetrol.p(100),
+                                              ])
+
+        plt.rcParams["axes.prop_cycle"] = self.rwth_color_cycle
+
         self.frmt = frmt
 
     @property
